<?php
/**
 * @package BWDPSB Blocks
 * Blocks Loader
 */

// Exit if accessed directly.
if ( !defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Blocks Loader Class
 */
class BWDPSB_PRODUCT_SHOWCASE_BLOCKS_LOADER {

    /**
     * Constructor
     */
    public function __construct() {
        // Register Blocks
        add_action( 'init', [ $this, 'register_blocks' ] );
        
        // Register Block Category
        if ( version_compare( BWDPSB_PRODUCT_SHOWCASE_WP_VERSION, '5.8', '>=' ) ) {
            add_filter( 'block_categories_all', [ $this, 'register_product_grid_block_category' ], 99999, 2 );
        } else {
            add_filter( 'block_categories', [ $this, 'register_product_grid_block_category' ], 99999, 2 );
        }
        
        // Enqueue Inline style on render block
        add_filter( 'render_block', [ $this, 'generate_inline_style_on_render_block' ], 10, 2 );
    
        // Enqueue editor assets
        add_action( 'enqueue_block_editor_assets', [ $this, 'enqueue_editor_assets' ] );
    
        // Enqueue assets for frontend
        add_action( 'enqueue_block_assets', [ $this, 'enqueue_assets' ] );
    
        // Add price to REST API response
        add_filter('rest_prepare_product', [ $this, 'add_price_to_rest_response' ], 10, 3);
    }
    
   
    
    /**
     * Enqueue Editor Assets
     */
    public function enqueue_editor_assets(){
        wp_enqueue_script(
            'bwdpsb-blocks-global-js',
            BWDPSB_PRODUCT_SHOWCASE_ADMIN_URL . '/dist/global.js',
            [],
            BWDPSB_PRODUCT_SHOWCASE_VERSION,
            true
        );
    }

    /**
     * Enqueue Assets
     */
     public function enqueue_assets(){
         wp_enqueue_style( 'bwdpsb-blocks-fontawesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css');
         wp_enqueue_script( 'bwdpsb-blocks-frontend', BWDPSB_PRODUCT_SHOWCASE_ADMIN_URL . './includes/assets/js/main.js', [], BWDPSB_PRODUCT_SHOWCASE_VERSION, true);
    }
    /**
     * Blocks Category
     */
    public function register_product_grid_block_category( $categories, $post ) {
        return array_merge(
            [
                [
                    'slug' => 'bwdpsb-product-showcase-blocks',
                    'title' => __( 'Product Showcase Block', 'bwdpsb-product-showcase' )
                ],
            ],
            $categories
        );
    }

    /**
     * Load Blocks
     */
    public function register_blocks() {
        
        // get all blocks from includes/blocks/blocks.php
        require_once BWDPSB_PRODUCT_SHOWCASE_DIR_PATH . './includes/blocks/blocks.php';

        // Register Blocks
        if( ! empty( $bwdpsb_product_showcase_blocks ) && is_array( $bwdpsb_product_showcase_blocks ) ) {
            foreach( $bwdpsb_product_showcase_blocks as $block ) {
                $this->register_single_block( $block );
            }
        }

    }

    /**
     * Register Single Block
     */
    public function register_single_block( $block ) {
        register_block_type(
            BWDPSB_PRODUCT_SHOWCASE_DIR_PATH . './build/blocks/' . $block['name'],
            [
                'render_callback' => [ $this, 'bwdpsb_product_showcase_render_callback']
            ]
        );
        
    }
    

    public function add_price_to_rest_response($response, $post, $request) {
        $product = wc_get_product($post->ID);
    
        if ($product) {
            if ($product->is_type('variable')) {
                $prices = array();
                $variations = $product->get_available_variations();
                foreach ($variations as $variation) {
                    $prices[] = wc_get_price_to_display(wc_get_product($variation['variation_id']));
                }
                sort($prices);
                $min_price = number_format($prices[0], wc_get_price_decimals());
                $max_price = number_format(end($prices), wc_get_price_decimals());
                $response->data['price_range'] = sprintf('%s - %s', $min_price, $max_price);
            } elseif ($product->is_type('grouped')) {
                $prices = array();
                $children = $product->get_children();
                foreach ($children as $child_id) {
                    $child_product = wc_get_product($child_id);
                    if ($child_product) {
                        $prices[] = wc_get_price_to_display($child_product);
                    }
                }
                if (!empty($prices)) {
                    sort($prices);
                    $min_price = number_format($prices[0], wc_get_price_decimals());
                    $max_price = number_format(end($prices), wc_get_price_decimals());
                    $response->data['price_range'] = sprintf('%s - %s', $min_price, $max_price);
                }
            } else {
                $regular_price = $product->get_regular_price() ? number_format($product->get_regular_price(), wc_get_price_decimals()) : null;
                $sale_price = $product->get_sale_price() ? number_format($product->get_sale_price(), wc_get_price_decimals()) : null;
                $response->data['regular_price'] = $regular_price;
                $response->data['sale_price'] = $sale_price;
            }
            $response->data['product_type'] = $product->get_type();
    
            // Add URLs based on product type
            if ($product->is_type('simple')) {
                $response->data['add_to_cart_url'] = $product->add_to_cart_url();
            } elseif ($product->is_type('variable') || $product->is_type('grouped')) {
                $response->data['details_page_url'] = get_permalink($post->ID);
            } elseif ($product->is_type('external')) {
                $response->data['add_to_cart_url'] = $product->get_product_url();
                $response->data['button_text'] = $product->get_button_text();
            }
    
            $response->data['currency_symbol'] = get_woocommerce_currency_symbol();
            $response->data['average_rating'] = $product->get_average_rating();
            $response->data['rating_count'] = $product->get_rating_count();
            $response->data['short_description'] = wp_strip_all_tags($product->get_short_description());
            
            // Get categories for the product
            $categories = get_the_terms($post->ID, 'product_cat');
            if ($categories && !is_wp_error($categories)) {
                $category_names = array();
                foreach ($categories as $category) {
                    $category_names[] = $category->name;
                }
                $response->data['categories'] = $category_names;
            }
        }
    
        return $response;
    }
    
    

    /**
     * Render callback for the BWD Advanced Post Block.
     */
        public function bwdpsb_product_showcase_render_callback ($attributes, $content){
            $productFilter = isset($attributes['productsFilter']) ? $attributes['productsFilter'] : 'latest_product';
            $selectedCategory = isset($attributes['selectedCategory']) ? $attributes['selectedCategory'] : [];
            $categoryIds = array_column($selectedCategory, 'value'); 
            $selectedTag = isset($attributes['selectedTag']) ? $attributes['selectedTag'] : [];
            $tagIds = array_column($selectedTag, 'value'); 
            $selectCustomPost = isset($attributes['includePosts']) ? $attributes['includePosts'] : [];
            $includeId = array_column($selectCustomPost, 'value');
            $removePost = isset($attributes['excludePosts']) ? $attributes['excludePosts'] : [];
            $excludeId = array_column($removePost, 'value');
            
            // Building the query arguments based on attributes
            $args = [
                'post_type' => 'product',
                "posts_per_page" => isset($attributes['numberOfProduct']) ? $attributes['numberOfProduct'] : 4,
                "order" => isset($attributes['order']) ? $attributes['order'] : '',
                "orderby" => isset($attributes['orderBy']) ? $attributes['orderBy'] : '',
                'post__in' => $includeId,
                'post__not_in' => $excludeId,
                'paged' => get_query_var('paged') ? get_query_var('paged') : 1, 
            ];

            $tax_query = [];

            switch ($productFilter) {
                case 'latest_product':
                    $args['date_query'] = [
                        [
                            'after' => '6 months ago',
						    'inclusive' => true,
                        ],
                    ];
                    break;
                case 'featured_product':
                    $tax_query[] = [
                        'taxonomy' => 'product_visibility',
                        'field' => 'name',
                        'terms' => 'featured',
                        'operator' => 'IN',
                    ];
                    break;
                case 'on_sale':
                    $args['meta_query'] = [
                        'relation' => 'OR',
                        [
                            'key' => '_sale_price',
                            'value' => 0,
                            'compare' => '>',
                            'type' => 'NUMERIC',
                        ],
                        [
                            'key' => '_sale_price',
                            'value' => '',
                            'compare' => '=',
                        ],
                    ];
                    break;
                case 'top_rated':
                    $args['meta_query'] = [
                        [
                            'key' => '_wc_average_rating',
                            'compare' => '>',
                            'value' => 0,
                            'type' => 'NUMERIC',
                        ],
                    ];
                    break;
                case 'best_selling':
                    $args['meta_query'] = [
                        [
                           'key' => 'total_sales',
                            'compare' => '>',
                            'value' => 0, 
                            'type' => 'NUMERIC',
                        ],
                    ];
                    break;
                case 'cheapest':
                    $args['meta_query'] = [
                        [
                           'key' => '_price',
                            'compare' => 'EXISTS',
                            'type' => 'NUMERIC',
                        ],
                        $args['orderby'] = 'meta_value_num',
				        $args['order'] = 'ASC',
                    ];
                    break;
                case 'low_to_high':
                    $args['meta_query'] = [
                        [
                           'key' => '_price',
                            'compare' => 'EXISTS',
                            'type' => 'NUMERIC',
                        ],
                        $args['orderby'] = 'meta_value_num',
				        $args['order'] = 'ASC',
                    ];
                    break;
                case 'high_to_low':
                    $args['meta_query'] = [
                        [
                            'key' => '_price',
                            'compare' => 'EXISTS',
                            'type' => 'NUMERIC',
                        ],
                    ];
                    $args['orderby'] = 'meta_value_num';
                    $args['order'] = 'DESC';
                    break;
                case 'new_arrivals':
                    $args['date_query'] = [
                        [
                            'after' => '1 month ago',
                            'inclusive' => true,
                        ],
                    ];
                    break;
                case 'free_shipping':
                    $args['meta_query'] = [
                        [
                            'key' => '_free_shipping',
                            'compare' => '=',
                            'value' => 'yes',
                        ],
                    ];
                    break;
                case 'popular_product':
                    $args['meta_query'] = [
                        [
                           'key' => 'total_sales',
                            'compare' => '>',
                            'value' => 0,
                            'type' => 'NUMERIC',
                        ],
                    ];
                    break;
                case 'in_stock':
                    $args['meta_query'] = [
                        [
                           'key' => '_stock_status',
						    'value' => 'instock',	
                        ],
                    ];
                    break;
                case 'out_of_stock':
                    $args['meta_query'] = [
                        [
                           'key' => '_stock_status',
						    'value' => 'outofstock',	
                        ],
                    ];
                    break;
                    default:
					'';
				break;
            }

            if (!empty($categoryIds)) {
                $tax_query[] = [
                    'taxonomy' => 'product_cat',
                    'field' => 'term_id',
                    'terms' => $categoryIds,
                ];
            }

            if (!empty($tagIds)) {
                $tax_query[] = [
                    'taxonomy' => 'product_tag',
                    'field' => 'term_id',
                    'terms' => $tagIds,
                ];
            }

            if (!empty($tax_query)) {
                $args['tax_query'] = $tax_query;
            }
            // Creating a new WP_Query instance
            $query = new WP_Query($args);

             // Extracting additional attributes
            $style = isset( $attributes['style'] ) ? $attributes['style'] : 'style-1';
            $container = isset( $attributes['containerWidth'] ) ? $attributes['containerWidth'] : 'container';
            $additionalClass = isset( $attributes['additionalClass'] ) ? $attributes['additionalClass'] : '';
            $show_header = isset( $attributes['showHeading'] ) ? $attributes['showHeading'] : false;
            $show_sub_header = isset( $attributes['showSubHeading'] ) ? $attributes['showSubHeading'] : false;
            $show_separator = isset( $attributes['showSeparator'] ) ? $attributes['showSeparator'] : false;
            $show_img_overlay = isset( $attributes['showImageOverlay'] ) ? $attributes['showImageOverlay'] : false;
            $show_product_img = isset( $attributes['showProductImage'] ) ? $attributes['showProductImage'] : false;
            $header_title = isset( $attributes['headerTitle'] ) ? $attributes['headerTitle'] : 'Header Title Here';
            $sub_heading = isset( $attributes['subHeading'] ) ? $attributes['subHeading'] : 'Sub Title Here';
            $show_featured_image = isset( $attributes['showProductImage'] ) ? $attributes['showProductImage'] : true;
            $enable_image_link = isset( $attributes['enableImageLink'] ) ? $attributes['enableImageLink'] : true;
            $show_title = isset( $attributes['showTitle'] ) ? $attributes['showTitle'] : true;
            $show_title_link = isset( $attributes['showTitleLink'] ) ? $attributes['showTitleLink'] : true;
            $show_description = isset( $attributes['showDescription'] ) ? $attributes['showDescription'] : true;
            $title_tag = isset( $attributes['titleTag'] ) ? $attributes['titleTag'] : 'h2';
            $show_sale_badge = isset( $attributes['showSaleBadge'] ) ? $attributes['showSaleBadge'] : true;
            $show_sale_text = isset( $attributes['showSaleText'] ) ? $attributes['showSaleText'] : true;
            $sale_text = isset( $attributes['saleText'] ) ? $attributes['saleText'] : 'Sale';
            $show_percentage = isset( $attributes['showPercentage'] ) ? $attributes['showPercentage'] : true;
            $percentage_text = isset( $attributes['percentageText'] ) ? $attributes['percentageText'] : 'Off';
            $show_price = isset( $attributes['showPrice'] ) ? $attributes['showPrice'] : true;
            $show_rating = isset( $attributes['showRating'] ) ? $attributes['showRating'] : true;
            $show_rating_count = isset( $attributes['showRatingCount'] ) ? $attributes['showRatingCount'] : true;
            $show_category = isset( $attributes['showCategory'] ) ? $attributes['showCategory'] : true;
            $desc_length = isset($attributes['descriptionLength']) ? absint($attributes['descriptionLength']) : 10;
            $title_length = isset($attributes['titleLength']) ? absint($attributes['titleLength']) : 5;
            $tail_indicator = isset( $attributes['wordsTailIndicator'] ) ? $attributes['wordsTailIndicator'] : '';
            $show_pagination = isset( $attributes['showPagination'] ) ? $attributes['showPagination'] : false;
            $pagi_prev_text = isset( $attributes['pagiPrevText'] ) ? $attributes['pagiPrevText'] : 'Previous';
            $pagi_next_text = isset( $attributes['pagiNextText'] ) ? $attributes['pagiNextText'] : 'Next';
            $read_more_text = isset( $attributes['readMoreText'] ) ? $attributes['readMoreText'] : 'Read More';
            $item_animation = isset( $attributes['animation'] ) ? $attributes['animation'] : '';
            $customCss = isset($attributes['customCSS']) ? $attributes['customCSS'] : '';
            $custom_id = isset($attributes['id']) ? $attributes['id'] : '';

            // Get block wrapper attributes
            $blocks_props = get_block_wrapper_attributes([
                'class' => $attributes['uniqueId'] . ' ' . $style . ' ' . $container . ' ' . ($additionalClass ? $additionalClass : '') . ' bwdpsb-responsive',
            ]);
            

             // Start output buffering
             
             // Ensure that the custom CSS is not empty
            if (!empty($customCss)) {
                echo '<style type="text/css">' . esc_html($customCss) . '</style>';
            }
            
            // Building the main markup
            if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
                ob_start();
                $markup = '<div '.$blocks_props.'>';
                // Post Header
                 if ($show_header) {
                    $markup .= '<div class="bwdpsb-header-title">';
                    $markup .= '<h2>' . esc_html($header_title) . '</h2>';
                    if ($show_sub_header) {
                        $markup .= '<p>' . esc_html($sub_heading) . '</p>';
                    }
                    if ($show_separator) {
                        $markup .= '<div></div>';
                    }
                    $markup .= '</div>';
                }
                $markup .= '<div class="bwdpsb-item-wrapper animate ' . esc_attr($item_animation) . '"' . ($custom_id ? ' id="' . esc_attr($custom_id) . '"' : '') . '>';
               
    
                // Loop through the query results
                if( $query->have_posts() ) {
                    while( $query->have_posts() ) {
                        $query->the_post();
    
                        // Get post categories
                        $categories = get_the_category();
                        // Get post permalink
                        $permalink = esc_url(get_permalink());
    
                        // Start building the product item markup
                        $markup .= '<div class="bwdpsb-product-item">';
                        $markup .= '<div class="bwdpsb-product-image';
                        $markup .= $show_img_overlay ? ' show-image-overlay' : '';
                        $markup .= '">';
                        $product_id = get_the_ID();
                        $product = wc_get_product($product_id);
                        $placeholder_image = plugin_dir_url(__FILE__) . 'assets/img/bwd-placeholder.jpg';
                        if ($product) {
                            $product_image = $product->get_image();
                            $permalink = get_permalink($product_id);
                            if ($product_image) {
                                if ($enable_image_link) {
                                    $markup .= '<a href="' . esc_url($permalink) . '">' . $product_image . '</a>';
                                } else {
                                    $markup .= $product_image;
                                }
                            } else {
                                $markup .= '<img src="' . esc_url($placeholder_image) . '" alt="Placeholder Image">';
                            }
                        }
                        $markup .= '</div>';
                        // Display the sale badge if the product is on sale
                        if ($show_sale_badge && $product->is_on_sale()) {
                            $regular_price = $product->get_regular_price();
                            $sale_price = $product->get_sale_price();
                        
                            if ($regular_price && $sale_price) {
                                // Calculate the sale percentage
                                $percentage_discount = round((($regular_price - $sale_price) / $regular_price) * 100);
                        
                                // Display percentage discount if enabled
                                if ($show_percentage) {
                                    $markup .= '<div class="bwdpsb-percentage bwdpsb-sale-general">-' . $percentage_discount . '% ' . $percentage_text . '</div>';
                                }
                        
                                // Display "Sale" text if enabled
                                if ($show_sale_text) {
                                    $markup .= '<div class="bwdpsb-sale-text bwdpsb-sale-general">' . $sale_text . '</div>';
                                }
                            }
                        }
                        // Product categories
                        $product_categories = get_the_terms(get_the_ID(), 'product_cat');
                        if ($product_categories && !is_wp_error($product_categories)) {
                            $category_names = [];
                            foreach ($product_categories as $category) {
                                $category_names[] = $category->name;
                            }
                            $markup .= '<div class="bwdpsb-product-category"><a href="#">' . implode(', ', $category_names) . '</a></div>';
                        }
                        // Post content section
                        $markup .= '<div class="bwdpsb-product-content">';
                        // Post title
                        if ($show_title) {
                            $title = wp_trim_words(get_the_title(), $title_length, '');
                            $title = rtrim($title, '.');
                            if ($show_title_link) {
                                $markup .= '<' . esc_html($title_tag) . ' class="bwdpsb-product-title"><a href="' . esc_url($permalink) . '">' . esc_html($title) . '</a></' . esc_html($title_tag) . '>';
                            } else {
                                $markup .= '<' . esc_html($title_tag) . ' class="bwdpsb-product-title">' . esc_html($title) . '</' . esc_html($title_tag) . '>';
                            }
                        }
                        // Short description
                        if ($product) {
                            if ($show_description) {
                                $short_description = $product->get_short_description();
                                
                                if (!empty($short_description)) {
                                    // Trim the description to the desired length
                                    $trimmed_description = wp_trim_words($short_description, $desc_length, $tail_indicator);
                                    $markup .= '<div class="bwdpsb-product-description">' . wp_kses_post($trimmed_description) . '</div>';
                                }
                            }
                            
                        $markup .= '<div class="bwdpsb-product-price-rating-wrap">';                   
                        // Product price
                        if($show_price) {
                            $currency_symbol = get_woocommerce_currency_symbol();
                            if ($product->is_type('variable')) {
                                // For variable products, show price range
                                $min_price = $product->get_variation_price('min', true);
                                $max_price = $product->get_variation_price('max', true);
                                if ($min_price !== $max_price) {
                                    $markup .= '<div class="bwdpsb-product-price">' . $currency_symbol . wc_format_decimal($min_price, 2) . ' - ' . $currency_symbol . wc_format_decimal($max_price, 2) . '</div>';
                                } else {
                                    $markup .= '<div class="bwdpsb-product-price">' . $currency_symbol . wc_format_decimal($min_price, 2) . '</div>';
                                }
                            } elseif ($product->is_type('grouped')) {
                                $children = $product->get_children();
                                $prices = [];
                                foreach ($children as $child_id) {
                                    $child_product = wc_get_product($child_id);
                                    if ($child_product) {
                                        $prices[] = $child_product->get_price();
                                    }
                                }
                                if (!empty($prices)) {
                                    $min_price = min($prices);
                                    $max_price = max($prices);
                                    if ($min_price !== $max_price) {
                                        $markup .= '<div class="bwdpsb-product-price">' . $currency_symbol . wc_format_decimal($min_price, 2) . ' - ' . $currency_symbol . wc_format_decimal($max_price, 2) . '</div>';
                                    } else {
                                        $markup .= '<div class="bwdpsb-product-price">' . $currency_symbol . wc_format_decimal($min_price, 2) . '</div>';
                                    }
                                }
                            } else {
                                // For simple products, show the regular and sale price
                                $regular_price = $product->get_regular_price();
                                $sale_price = $product->get_sale_price();
                                if ($sale_price) {
                                    $markup .= '<div class="bwdpsb-product-price"><span class=regular-price><del>' . $currency_symbol . wc_format_decimal($regular_price, 2) . '</del></span><span class="sale-price">' . $currency_symbol . wc_format_decimal($sale_price, 2) . '</span></div>';
                                } else {
                                    $markup .= '<div class="bwdpsb-product-price">' . $currency_symbol . wc_format_decimal($regular_price, 2) . '</div>';
                                }
                            }
    
                        }
    
                            // Star Rating
                            if (wc_review_ratings_enabled() && $show_rating) {
                                $average = $product->get_average_rating();
                                $rating_count = $product->get_rating_count();
                                    $markup .= '<div class="bwdpsb-product-rating-wrap">';
                                    $markup .= '<div class="bwdpsb-product-rating">';
                                    for ($i = 1; $i <= 5; $i++) {
                                        if ($i <= $average) {
                                            $markup .= '<span className="star-rating"><i class="fas fa-star"></i></span>';
                                        } else {
                                            $markup .= '<span className="star-rating"><i class="far fa-star"></i></span>'; 
                                        }
                                    }
                                    $markup .= '</div>';
                                    if($show_rating_count) {
                                        $markup .= '<div class="bwdpsb-product-rating-count">(' . $rating_count . ')</div>';
                                    }
                                    $markup .= '</div>';
                            }
                            $markup .= '</div>';
                            // "Add to Cart" button with cart icon
                            $product_id = get_the_ID();
                            $product = wc_get_product($product_id);
                            $product_permalink = get_permalink($product_id);
        
                            if ($product) {
                                if ($product->is_type('simple')) {
                                    $add_to_cart_url = esc_url(add_query_arg('add-to-cart', $product_id));
                                    $markup .= '<div class="bwdpsb-add-to-cart"><a href="' . $add_to_cart_url . '" class="bwdpsb-add-to-cart-button"><i class="fas fa-cart-plus"></i> Add to Cart</a></div>';
                                } elseif ($product->is_type('variable') || $product->is_type('grouped')) {
                                    $markup .= '<div class="bwdpsb-add-to-cart"><a href="' . esc_url($product_permalink) . '" class="bwdpsb-add-to-cart-button"><i class="fas fa-cart-plus"></i>View Products</a></div>';
                                } elseif ($product->is_type('external')) {
                                    $external_url = $product->get_product_url();
                                    $button_text = $product->get_button_text();
                                    $markup .= '<div class="bwdpsb-external-product"><a href="' . esc_url($external_url) . '" class="bwdpsb-add-to-cart-button" target="_blank"><i class="fas fa-cart-plus"></i>' . esc_html($button_text) . '</a></div>';
                                }
                            }
        
                        }
                            $markup .= '</div>';
                            
                            $markup .= '</div>';
                        }
                    // Reset product data after the loop
                    wp_reset_postdata();
                }
                $markup .= '</div>';
                // Pagination
                if ($show_pagination) {
                    $pagination_args = array(
                        'total'      => $query->max_num_pages,
                        'prev_text'  => '<svg enable-background="new 0 0 477.175 477.175" version="1.1" viewBox="0 0 477.18 477.18"><path d="m145.19 238.58 215.5-215.5c5.3-5.3 5.3-13.8 0-19.1s-13.8-5.3-19.1 0l-225.1 225.1c-5.3 5.3-5.3 13.8 0 19.1l225.1 225c2.6 2.6 6.1 4 9.5 4s6.9-1.3 9.5-4c5.3-5.3 5.3-13.8 0-19.1l-215.4-215.5z"></path></svg><span>' . esc_html($pagi_prev_text) . '</span>',
                        'next_text'  => '<span>' . esc_html($pagi_next_text) . '</span><svg enable-background="new 0 0 477.175 477.175" version="1.1" viewBox="0 0 477.18 477.18"><path d="m360.73 229.08-225.1-225.1c-5.3-5.3-13.8-5.3-19.1 0s-5.3 13.8 0 19.1l215.5 215.5-215.5 215.5c-5.3 5.3-5.3 13.8 0 19.1 2.6 2.6 6.1 4 9.5 4s6.9-1.3 9.5-4l225.1-225.1c5.3-5.2 5.3-13.8 0.1-19z"></path></svg>',
                        'type'       => 'list',
                    );
                
                    $pagination_links = paginate_links($pagination_args);
                
                    // Add custom class to <ul> element
                    $pagination_links = preg_replace('/<ul class=\'page-numbers\'/', '<ul class=\'page-numbers bwdpsb-pagination\'', $pagination_links);
                
                    echo $pagination_links;
                }
                
                $markup .= '</div>';
    
    
                // End output buffering and return the markup
                $markup .= ob_get_clean();
    
                return $markup;   

            } else {
                ?>
                  <div>
                    <p class="error notice"><?php
                        printf(
                            esc_html__(
                                'WooCommerce is not active. Please <a href="%s">install and activate WooCommerce</a> to use this plugin.',
                                'your-plugin-textdomain'
                            ),
                            esc_url( admin_url( 'plugin-install.php?s=woocommerce&tab=search&type=term' ) )
                        );
                    ?></p>
                </div>

                <?php
            }
        }


    /**
     * Register Inline Style
     */
    function generate_inline_style_on_render_block($block_content, $block ) {

        if (isset($block['blockName']) && str_contains($block['blockName'], 'bwdpsb/')) {
            if (isset($block['attrs']['blockStyle'])) {

                $style = $block['attrs']['blockStyle'];
                $handle = isset( $block['attrs']['uniqueId'] ) ? $block['attrs']['uniqueId'] : 'bwdpsb-product-showcase';

                // convert style array to string
                if ( is_array($style) ) {
                    $style = implode(' ', $style);
                }

                // minify style to remove extra space
                $style = preg_replace( '/\s+/', ' ', $style );

                wp_register_style(
                    $handle,
                    false,
                    [],
                    BWDPSB_PRODUCT_SHOWCASE_VERSION
                );
                wp_enqueue_style( $handle );
                wp_add_inline_style( $handle, $style );

            }
        }
        return $block_content;
    }

}

new BWDPSB_PRODUCT_SHOWCASE_BLOCKS_LOADER();